@@ -12,9 +12,11 @@ import qualified GI.Pango.Config as Pango
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Vte"
         version = "2.91"
+        pkgName = "gi-vte"
+        pkgVersion = "2.91.29"
         overridesFile = Just "Vte.overrides"
         verbose = False
         outputDir = Nothing
